# Generated by Django 3.2 on 2023-07-05 18:07

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Function',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.TextField(blank=True, default='', null=True)),
                ('val', models.TextField(blank=True, default='', null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Password',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.TextField(blank=True, default='', null=True)),
                ('val', models.TextField(blank=True, default='', null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Variable',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.TextField(blank=True, default='', null=True)),
                ('val', models.TextField(blank=True, default='', null=True)),
            ],
        ),
    ]



from django.http import HttpResponse , JsonResponse , Http404
import json
from .models import Variable, Function, Password
import pdb
from .utils import JSONDecode
import random

def check_password(request):
    if request.body == b"":
        return [0, JsonResponse({
            "errormsg" : "no body" , 
            "errorflag": True,
        })]

    password = str( JSONDecode(request.body).get("password") )
    if len(Password.objects.filter(val = password)) == 0: # not a valid password
        return [0, JsonResponse({
            "errormsg" : "not a valid password" , 
            "errorflag": True,
        })]

    return [1, None]

def get_variable(request , key):

    flag, info = check_password(request)
    if flag == 0:
        return info

    var = Variable.objects.filter(key = key)
    if len(var) == 0: # no such variable
        return JsonResponse({
            "errormsg" : "can't find variable" , 
            "errorflag": True,
        })
    var = var [0]

    return JsonResponse({
        "val": var.val , 
        "errorflag": False , 
    })

def get_function(request , key):

    flag, info = check_password(request)
    if flag == 0:
        return info

    fun = Function.objects.filter(key = key)
    if len(fun) == 0: # no such function
        return JsonResponse({
            "errormsg" : "can't find function" , 
            "errorflag": True,
        })
    fun = fun [0]

    val_raw = str(fun.val)
    val = val_raw
    for var in Variable.objects.all(): # 也许有不这么粗暴的方法...
        val = val.replace( "${" + str(var.key) + "}" , str(var.val))


    return JsonResponse({
        "val": {
            "content": val , 
            "type": fun.type , 
        } , 
        "content_raw": val_raw , 
        "errorflag": False , 
    })

def get_rand_str():
	s = ""
	for i in range(10):
		s += "qwertyuioplkjhgfdsazxcvbnm"[random.randint(0,26-1)]
	return s

def add_password(request , key):

    flag, info = check_password(request)
    if flag == 0:
        return info

    new_pass = Password(key = key, val = get_rand_str())
    new_pass.save()


    return JsonResponse({
        "val": new_pass.val , 
        "errorflag": False , 
    })

def delete_password(request , key):

    flag, info = check_password(request)
    if flag == 0:
        return info

    Password.objects.filter(key = key).delete()

    return JsonResponse({
        "errorflag": False , 
    })



from django.db import models

# Create your models here.

class Variable(models.Model):
    key = models.TextField(default = "", blank = True, null = True)
    val = models.TextField(default = "", blank = True, null = True)

    def __str__(self):
        return str(self.key)
    
class Function(models.Model):
    key = models.TextField(default = "", blank = True, null = True)
    val = models.TextField(default = "", blank = True, null = True)
    type = models.TextField(default = "cmd", blank = True, null = True)

    def __str__(self):
        return str(self.key)

class Password(models.Model):
    key = models.TextField(default = "", blank = True, null = True)
    val = models.TextField(default = "", blank = True, null = True)

    def __str__(self):
        return str(self.key)




from . import get_function
import sys
import os
import tempfile
from YTools import python_run

def run():
    argv = sys.argv
    
    if len(argv) == 1:
        return 
    
    function = get_function(argv[1])

    if function["type"] == "cmd":
        os.system(function["content"])
    if function["type"] == "python":
        python_run(function["content"])

if __name__ == "__main__":
    sys.argv = ["", "test"]
    run()    
    sys.argv = ["", "test_python"]
    run()



from YTools.network.server.server import start_server
import os
import sys
import argparse
import urllib.request
import urllib.parse
import time
import pdb
import requests
import json
from functools import partial

def ask_ip(): # 这个函数向环境变量中询问远端的地址
    server_ip = os.environ.get("EGOROV_SERVER")
    if server_ip is None:
        server_ip = input("server ip = ")
    return server_ip.strip()

def ask_password(): # 这个函数询问密码
    if os.environ.get("EGOROV_PWD"): # 只在个人计算机上存密码
        return os.environ["EGOROV_PWD"]
    return input("password = ").strip()

def get_data(server_ip, password, key, type):
    return requests.post("http://{0}/get/{1}/{2}".format(server_ip, type, key), json = {"password": password}).json()

def run():
    # os.chdir(os.path.dirname(__file__))
    # sys.path.append(os.path.abspath("."))
    
    server_ip = ask_ip() # 获得远端地址
    password = ask_password()

    C = argparse.ArgumentParser()
    C.add_argument("--port" , type = int , default = 11451)
    C = C.parse_args()

    def ask_variable(request, key):
        return get_data(server_ip, password, key, "variable")
    def ask_function(request, key):
        return get_data(server_ip, password, key, "function")
    def hello(request):
        return "hello"
    start_server(ip = "127.0.0.1" , port = C.port , responsers = {
        "hello":  hello, 
        "ask_variable/<str:key>":  ask_variable, 
        "ask_function/<str:key>":  ask_function, 
    } , encode = "json" , cross_domain = True)

if __name__ == "__main__":
    run()